@@ -1487,61 +1487,6 @@ eel_background_reset (EelBackground *background)
 	g_signal_emit (GTK_OBJECT (background), signals[RESET], 0);
 }
 
-static void
-draw_background_callback (EelCanvas *canvas, 
-			  int x, int y, int width, int height)
-{
-	EelBackground *background;
-	GdkGCValuesMask value_mask;
-	GdkDrawable *drawable;
-	GdkGCValues gc_values;
-	GdkGC *gc;
-	gboolean bg_changed;
-
-	background = eel_get_widget_background (GTK_WIDGET (canvas));
-	if (background == NULL) {
-		return;
-	}
-
-	drawable = canvas->layout.bin_window;
-	
-	bg_changed = eel_background_ensure_realized (background, GTK_WIDGET (canvas)->window,
-						     MAX (GTK_LAYOUT (canvas)->hadjustment->upper, GTK_WIDGET (canvas)->allocation.width),
-						     MAX (GTK_LAYOUT (canvas)->vadjustment->upper, GTK_WIDGET (canvas)->allocation.height));
-
-	if (bg_changed) {
-		/* The background changed, issue a full redraw */
-		/* This is needed to handle gradients that grow on resize */
-		gtk_widget_queue_draw (GTK_WIDGET (canvas));
-	}
-
-	/* Create a new gc each time.
-	 * If this is a speed problem, we can create one and keep it around,
-	 * but it's a bit more complicated to ensure that it's always compatible
-	 * with whatever drawable is passed in.
-	 */
-	if (background->details->background_pixmap != NULL) {
-		gc_values.tile = background->details->background_pixmap;
-		gc_values.ts_x_origin = 0;
-		gc_values.ts_y_origin = 0;
-		gc_values.fill = GDK_TILED;
-		value_mask = GDK_GC_FILL | GDK_GC_TILE |
-			GDK_GC_TS_X_ORIGIN | GDK_GC_TS_Y_ORIGIN;
-	} else {
-		gc_values.foreground = background->details->background_color;
-		gdk_rgb_find_color (gtk_widget_get_colormap (GTK_WIDGET (canvas)), &gc_values.foreground);
-		gc_values.fill = GDK_SOLID;
-		value_mask = GDK_GC_FILL | GDK_GC_FOREGROUND;
-	}
-		
-    	gc = gdk_gc_new_with_values (drawable, &gc_values, value_mask);
-	gdk_draw_rectangle (drawable, gc, TRUE, x, y, width, height);
-	g_object_unref (gc);
-
-	/* We don't want the draw from the base class to happen. */
-	g_signal_stop_emission_by_name (canvas, "draw_background");
-}
-
 static void
 eel_background_set_up_widget (EelBackground *background, GtkWidget *widget)
 {
@@ -1551,6 +1496,7 @@ eel_background_set_up_widget (EelBackground *background, GtkWidget *widget)
 	int window_width;
 	int window_height;
 	GdkWindow *window;
+	GdkScreen *screen;
 	gboolean changes_with_size;
 
 	if (!GTK_WIDGET_REALIZED (widget)) {
@@ -1558,6 +1504,16 @@ eel_background_set_up_widget (EelBackground *background, GtkWidget *widget)
 	}
 
 	gdk_drawable_get_size (widget->window, &window_width, &window_height);
+
+	/* HACK HACK HACK HACK
+	 * Hack to work around the fact that bonoboplug/socket first realizes
+	 * the child at the wrong size. This allows us to avoid re-reading the
+	 * image when we later get the right size */
+	if (g_object_get_data (G_OBJECT (background), "is_desktop") != 0) {
+		screen = gtk_widget_get_screen (widget);
+		window_width = gdk_screen_get_width (screen);
+		window_height = gdk_screen_get_height (screen);
+	}
 	
 	pixmap = eel_background_get_pixmap_and_color (background,
 						      widget->window,
@@ -1587,28 +1543,11 @@ eel_background_set_up_widget (EelBackground *background, GtkWidget *widget)
 	}
 }
 
-static void
-eel_background_set_up_canvas (GtkWidget *widget)
-{
-	if (!EEL_IS_CANVAS (widget)) {
-		return;
-	}
-	if (g_object_get_data (G_OBJECT (widget), "eel_background_canvas_is_set_up") != NULL) {
-		return;
-	}
-
-	g_signal_connect (widget, "draw_background",
-			  G_CALLBACK (draw_background_callback), NULL);
-
-	g_object_set_data (G_OBJECT (widget), "eel_background_canvas_is_set_up", widget);
-}
-
 static void
 eel_widget_background_changed (GtkWidget *widget, EelBackground *background)
 {
 	eel_background_unrealize (background);
 	eel_background_set_up_widget (background, widget);
-	eel_background_set_up_canvas (widget);
 
 	gtk_widget_queue_draw (widget);
 }
