@@ -28,13 +28,13 @@
 #include "eel-glib-extensions.h"
 #include "eel-gnome-extensions.h"
 #include "eel-string.h"
+#include "eel-i18n.h"
 #include <gtk/gtkbox.h>
 #include <gtk/gtklabel.h>
 #include <gtk/gtkmain.h>
 #include <gtk/gtkmessagedialog.h>
 #include <gtk/gtksignal.h>
 #include <gtk/gtkstock.h>
-#include <libgnome/gnome-i18n.h>
 #include <libgnomeui/gnome-uidefs.h>
 
 #define TIMED_WAIT_STANDARD_DURATION 2000
@@ -121,11 +121,11 @@ timed_wait_delayed_close_timeout_callback (gpointer callback_data)
 	guint handler_id;
 
 	handler_id = GPOINTER_TO_UINT (g_object_get_data (G_OBJECT (callback_data),
-							    "eel-stock-dialogs/delayed_close_handler_timeout_id"));
+							  "eel-stock-dialogs/delayed_close_handler_timeout_id"));
 	
-	gtk_signal_disconnect_by_func (GTK_OBJECT (callback_data),
-			    	       G_CALLBACK (timed_wait_delayed_close_destroy_dialog_callback),
-			    	       GUINT_TO_POINTER (handler_id));
+	g_signal_handlers_disconnect_by_func (G_OBJECT (callback_data),
+					      G_CALLBACK (timed_wait_delayed_close_destroy_dialog_callback),
+					      GUINT_TO_POINTER (handler_id));
 	
 	gtk_object_destroy (GTK_OBJECT (callback_data));
 
@@ -154,9 +154,9 @@ timed_wait_free (TimedWait *wait)
 		/* Make sure to detach from the "destroy" signal, or we'll
 		 * double-free.
 		 */
-		gtk_signal_disconnect_by_func (GTK_OBJECT (wait->dialog),
-					       G_CALLBACK (timed_wait_dialog_destroy_callback),
-					       wait);
+		g_signal_handlers_disconnect_by_func (G_OBJECT (wait->dialog),
+						      G_CALLBACK (timed_wait_dialog_destroy_callback),
+						      wait);
 
 		/* compute time up in milliseconds */
 		time_up = (eel_get_system_time () - wait->dialog_creation_time) / 1000;
@@ -221,9 +221,9 @@ timed_wait_callback (gpointer callback_data)
 	 * sizing do its thing. This enforces a minimum width to
 	 * make it more likely that the title won't be clipped.
 	 */
-	gtk_widget_set_usize (GTK_WIDGET (dialog),
-			      TIMED_WAIT_MINIMUM_DIALOG_WIDTH,
-			      -1);
+	gtk_window_set_default_size (GTK_WINDOW (dialog),
+				     TIMED_WAIT_MINIMUM_DIALOG_WIDTH,
+				     -1);
 	gtk_window_set_wmclass (GTK_WINDOW (dialog), "dialog", "Eel");
 	add_label_to_dialog (dialog, wait->wait_message);
 	wait->dialog_creation_time = eel_get_system_time ();
@@ -320,16 +320,6 @@ eel_timed_wait_stop (EelCancelCallback cancel_callback,
 	timed_wait_free (wait);
 }
 
-static gboolean
-delete_event_callback (gpointer data,
-		       gpointer user_data)
-{
-	g_return_val_if_fail (GTK_IS_DIALOG (data), FALSE);
-	gtk_signal_emit_stop_by_name (GTK_OBJECT (data),
-				      "delete_event");
-	return TRUE;
-}
-
 int
 eel_run_simple_dialog (GtkWidget *parent, gboolean ignore_close_box,
 		       const char *text, const char *title, ...)
@@ -365,15 +355,6 @@ eel_run_simple_dialog (GtkWidget *parent, gboolean ignore_close_box,
 	}
 	va_end (button_title_args);
 	
-	/* Allow close. */
-	if (ignore_close_box) {
-		g_signal_connect (dialog,
-				    "delete_event",
-				    G_CALLBACK (delete_event_callback),
-				    NULL);
-
-	}
-	
 	gtk_window_set_wmclass (GTK_WINDOW (dialog), "dialog", "Eel");
 
 	/* Title it if asked to. */
@@ -382,7 +363,7 @@ eel_run_simple_dialog (GtkWidget *parent, gboolean ignore_close_box,
 	/* Run it. */
         gtk_widget_show_all (dialog);
         result = gtk_dialog_run (GTK_DIALOG (dialog));
-	while (result == -1 && ignore_close_box) {
+	while ((result == GTK_RESPONSE_NONE || result == GTK_RESPONSE_DELETE_EVENT) && ignore_close_box) {
 		gtk_widget_show (GTK_WIDGET (dialog));
 		result = gtk_dialog_run (GTK_DIALOG (dialog));
 	}
@@ -414,18 +395,24 @@ show_message_dialog (const char *message,
 		     const char *dialog_title,
 		     GtkMessageType type,
 		     GtkButtonsType buttons_type,
-		     const char *additional_button,
+		     const char *additional_button_label,
 		     int additional_button_response_id,
 		     GtkWindow *parent)
 {
 	GtkDialog *dialog;
+	GtkWidget *additional_button;
+	GtkWidget *box;
 
 	dialog = create_message_dialog (message, dialog_title, type, 
 					buttons_type, parent);
-	if (additional_button != NULL) {
-		gtk_dialog_add_button (dialog,
-				       additional_button,
-				       additional_button_response_id);
+	if (additional_button_label != NULL) {
+		additional_button = gtk_dialog_add_button (dialog,
+							   additional_button_label,
+							   additional_button_response_id);
+		box = gtk_widget_get_parent (additional_button);
+		if (GTK_IS_BOX (box)) {
+			gtk_box_reorder_child (GTK_BOX (box), additional_button, 0);
+		}
 	}
 	gtk_widget_show (GTK_WIDGET (dialog));
 
@@ -505,10 +492,14 @@ eel_show_info_dialog_with_details (const char *info,
 				      GTK_BUTTONS_OK, _("Details"), RESPONSE_DETAILS,
 				      parent);
 
-	gtk_signal_connect_full (GTK_OBJECT (dialog), "response",
-				 G_CALLBACK (details_dialog_response_callback),
-				 NULL, g_strdup (detailed_info),
-				 g_free, FALSE, FALSE);
+
+	g_signal_connect_closure (G_OBJECT (dialog),
+				  "response",
+				  g_cclosure_new (
+					  G_CALLBACK (details_dialog_response_callback),
+					  g_strdup (detailed_info),  
+					  (GClosureNotify) g_free),
+				  FALSE);
 
 	return dialog;
 
@@ -560,11 +551,12 @@ eel_show_error_dialog_with_details (const char *error_message,
 				      parent);
 	
 	/* Show the details when you click on the details button. */
-	gtk_signal_connect_full (GTK_OBJECT (dialog), "response",
-				 G_CALLBACK (details_dialog_response_callback),
-				 NULL, g_strdup (detailed_error_message),
-				 g_free, FALSE, FALSE);
-
+	g_signal_connect_closure (G_OBJECT (dialog), "response",
+				  g_cclosure_new (
+					  G_CALLBACK (details_dialog_response_callback),
+					  g_strdup (detailed_error_message),  
+					  (GClosureNotify) g_free),
+				  FALSE);
 	return dialog;
 }
 
@@ -587,11 +579,14 @@ eel_show_yes_no_dialog (const char *question,
 			const char *no_label,
 			GtkWindow *parent)
 {
-	return show_message_dialog (question,
-				    dialog_title == NULL ? _("Question") : dialog_title, 
-				    GTK_MESSAGE_QUESTION,
-				    GTK_BUTTONS_YES_NO, NULL, 0,
-				    parent);
+	GtkDialog *dialog = 0;
+	dialog = eel_create_question_dialog (question,
+					     dialog_title == NULL ? _("Question") : dialog_title,
+					     no_label, GTK_RESPONSE_CANCEL,
+					     yes_label, GTK_RESPONSE_YES,
+					     GTK_WINDOW (parent));
+	gtk_widget_show (GTK_WIDGET (dialog));
+	return dialog;
 }
 
 /**
